/*
 * config.h - Reads XML configuration files.
 *
 * Copyright (C) 2006 - 2008 Andreas Scherrer, www.hifidelio-user.de
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 * USA.
 */

/**
 * \file config.h
 * Reads XML configuration files.
 */

#ifndef _CONFIG_H_
#define _CONFIG_H_

/**
 * Value for non-configured ports.
 */
#define CONFIG_NO_PORT -1

/**
 * Configuration data of a VNC screen.
 */
struct config_screen {
	int  vnc_port;      /**< VNC port number (Remote Framebuffer Protocol). */
	int  http_port;     /**< HTTP port number (Java viewer applet). */
	int  show_cursor;   /**< Show remote cursor; 0 : no, >= 1 : yes. */
	int  mouse_control; /**< Mouse control within display area; 0 : no, >= 1 : yes. */
	char *name;         /**< Screen name displayed in the title bar. */
	char *theme_dir;    /**< Directory with theme files. */
};

/**
 * Configuration data, including common and screen data.
 */
struct config {
	int  refresh;                   /**< Refresh delay in milliseconds. */
	int  key_repeat_delay;          /**< Key repeat delay in milliseconds. */
	char *auth_file;                /**< Password authentication file. */
	int  screen_count;              /**< Number of VNC screens. */
	struct config_screen **screens; /**< VNC screens. */
};

/*
 * Module functions.
 */
struct config *config_load(char *config_file);
void config_cleanup(struct config *config);

#endif /* !_CONFIG_H_ */

