/*
 * execsh.c - Executes shell commands.
 *
 * Copyright (C) 2006 - 2008 Andreas Scherrer, www.hifidelio-user.de
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 * USA.
 */

/**
 * \file execsh.c
 * Executes shell commands. Process execution occurs in the background.
 */

#include <stdlib.h>
#include <string.h>
#include <rfb/rfb.h>
#include "execsh.h"

/**
 * System path environment variable.
 */
#define ENV_PATH "PATH"

/**
 * System path for command execution.
 */
#define SYS_PATH \
"\
/audio/opt/coverart/bin:\
/opt/cdparanoia/bin:\
/opt/libxml2/bin:\
/opt/libshout/bin:\
/opt/icecast/bin:\
/opt/libxslt/bin:\
/opt/veronica/bin:\
/opt/flac/bin:\
/opt/Fidelio/bin:\
/opt/id3/bin:\
/opt/joe/bin:\
/opt/sox/bin:\
/opt/apache/bin:\
/opt/samba/bin:\
/opt/samba/sbin:\
/opt/sg3_utils/bin:\
/opt/schily/bin:\
/opt/schily/sbin:\
/opt/libiconv/bin:\
/opt/udhcp/bin:\
/opt/udhcp/sbin:\
/opt/zcip/sbin:\
/opt/zebra/sbin:\
/opt/gnupg/bin:\
/opt/wget/bin:\
/opt/dnsmasq/sbin:\
/opt/alsa-utils/sbin:\
/opt/alsa-utils/bin:\
/opt/alsa/bin:\
/opt/hfsplusutils/bin:\
/opt/disktype/bin:\
/opt/perl/bin:\
/opt/opt/veronica/bin:\
/opt/vorbistools/bin:\
/opt/jpeg/bin:\
/opt/ntp/bin:\
/opt/fcgi/bin:\
/opt/hostapd/bin:\
/opt/wpa_supplicant/bin:\
/opt/wpa_supplicant/sbin:\
/bin:\
/sbin:\
/usr/bin:\
/usr/sbin:\
/usr/local/bin:\
/usr/local/sbin"

/**
 * Executes a shell command in the background.
 * @param command  the shell command
 * @return 0 on success or -1 if an error occured
 */
int execsh_exec(char *command)
{
	char *exec_cmd;
	static int path_set = 0;

	if (!path_set) {
		if (setenv(ENV_PATH, SYS_PATH, 1) != 0) {
			rfbLogPerror("execsh_exec: putenv");
		}
		path_set = 1;
	}

	if (command == NULL || (command != NULL && strlen(command) == 0)) {
		rfbLog("execsh_exec: No shell command to execute\n");
		goto error;
	}
	
	if ((exec_cmd = malloc(strlen(command) + 3)) == NULL) {
		rfbLogPerror("execsh_exec: malloc");
		goto error;
	}
	strcpy(exec_cmd, command);
	strcat(exec_cmd, " &");
	rfbLog("Command: '%s'\n", exec_cmd);
	system(exec_cmd);
	
	free(exec_cmd);
	return 0;

error:	
	free(exec_cmd);
	return -1;
}

