/*
 * img.h - Reads image files (BMP, PNG, JPG).
 * 
 * Copyright (C) 2006 - 2008 Andreas Scherrer, www.hifidelio-user.de
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 * USA.
 */

/**
 * \file img.h
 * Reads image files (BMP, PNG, JPG).
 */

#ifndef _IMG_H_
#define _IMG_H_

/**
 * Value to ignore alpha channel in ::img_read calls.
 */
#define IMG_IGNORE_ALPHA 0

/**
 * Value to preserve alpha channel in ::img_read calls.
 */
#define IMG_PRESERVE_ALPHA 1

/**
 * Image data, including image bitmap.
 */
struct img_bitmap{
	long width;                 /**< Bitmap width. */
	long height;                /**< Bitmap height. */
	unsigned long transparency; /**< Transparency color. */
	int alpha_channel;          /**< Alpha channel flag. */
	void *pixels;               /**< Pixel data (n * 4 bytes of R, G, B, Alpha). */
};

/*
 * Module functions.
 */
struct img_bitmap *img_read(char *filename, int alpha_mode);
void   img_free(struct img_bitmap *bitmap);
	
#endif /* !_IMG_H_ */

