/*
 * theme.h - Reads theme XML files and obtains the necessary data.
 * 
 * Copyright (C) 2006 - 2008 Andreas Scherrer, www.hifidelio-user.de
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 * USA.
 */

/**
 * \file theme.h
 * Reads theme XML files. Fills a #theme structure with the obtained data.
 */

#ifndef _THEME_H_
#define _THEME_H_

#include "img.h"

/**
 * Theme data for a button.
 */
struct theme_button {
	char *name;	  /**< Button name. */
	int keycode;  /**< Corresponding keyboard code. */
	int modifier; /**< Corresponding keyboard modifier. */
	int x;        /**< Upper left x-coordinate of button. */
	int y;        /**< Upper left y-coordinate of button. */
	int width;    /**< Width of button. */
	int height;   /**< Height of button. */
	int active;   /**< State of button (1: active, 0: inactive). */
	char *exec;   /**< Shell command to execute. */
};

/**
 * Theme data for a display area.
 */
struct theme_display {
	int x;        /**< Upper left x-coordinate of display. */
	int y;        /**< Upper left y-coordinate of display. */
	double scale; /**< Scale factor of display. */
	int width;    /**< Width of visible display area. */
	int height;   /**< Height of visible display area. */
	unsigned long forecolor; /**< Foreground color of display. */
};

/**
 * Theme data for a cover area.
 */
struct theme_cover {
	int x;        /**< Upper left x-coordinate of cover area. */
	int y;        /**< Upper left y-coordinate of cover area. */
	int width;    /**< Width of cover area. */
	int height;   /**< Height of cover area. */
	int rotate;   /**< Cover rotation (90, 180, 270 degrees). */
};

/**
 * Theme data for a key.
 */
struct theme_key {
	char *name;	  /**< Key name. */
	int code;     /**< Keycode. */
	int modifier; /**< Key modifier. */
	char *exec;   /**< Shell command to execute. */
};

/**
 * The whole theme data.
 */
struct theme {
	char *directory;                      /**< Theme directory. */
	struct theme_display *display;        /**< Display area data. */
	struct img_bitmap    *layout_bitmap;  /**< Layout bitmap data. */
	struct img_bitmap    *buttons_bitmap; /**< Buttons bitmap data. */
	struct theme_cover   *cover;          /**< Cover area data. */
	struct theme_button  **buttons;       /**< Buttons data. */
	struct theme_key     **keys;          /**< Keys data. */
	int button_count;                     /**< Number of buttons. */
	int key_count;                        /**< Number of keys. */
};

/*
 * Module functions.
 */
struct theme *theme_load(char *theme_dir);
void   theme_cleanup(struct theme *theme);

#endif /* !_THEME_H_ */

